summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorBram Moolenaar <Bram@vim.org>2010-07-21 16:00:43 +0200
committerBram Moolenaar <Bram@vim.org>2010-07-21 16:00:43 +0200
commitb65905262bc250810b4b3b5fedc4302c6cc4c9d2 (patch)
tree0ae4be3b7c281b030282f3445b8e4559172255dd
parentb8521960d660465208303254b47ad76cd7e3ef0e (diff)
Fix that :py3file was not working.
-rw-r--r--runtime/doc/if_pyth.txt4
-rw-r--r--runtime/doc/index.txt5
-rw-r--r--runtime/doc/todo.txt4
-rw-r--r--src/ex_cmds.h2
-rw-r--r--src/ex_docmd.c6
5 files changed, 15 insertions, 6 deletions
diff --git a/runtime/doc/if_pyth.txt b/runtime/doc/if_pyth.txt
index e3822ec0a8..953d95b8d5 100644
--- a/runtime/doc/if_pyth.txt
+++ b/runtime/doc/if_pyth.txt
@@ -1,4 +1,4 @@
-*if_pyth.txt* For Vim version 7.3b. Last change: 2010 Jul 20
+*if_pyth.txt* For Vim version 7.3b. Last change: 2010 Jul 21
VIM REFERENCE MANUAL by Paul Moore
@@ -335,7 +335,7 @@ sure edit "gvim.exe" and search for "python\d*.dll\c".
Python 3 support can exist next to Python 2.x.
-*:py3* *:py3file*
+*:py3* *:python3* *:py3file*
TODO
diff --git a/runtime/doc/index.txt b/runtime/doc/index.txt
index 0928e87fda..c82605c47a 100644
--- a/runtime/doc/index.txt
+++ b/runtime/doc/index.txt
@@ -1,4 +1,4 @@
-*index.txt* For Vim version 7.3b. Last change: 2010 Jul 20
+*index.txt* For Vim version 7.3b. Last change: 2010 Jul 21
VIM REFERENCE MANUAL by Bram Moolenaar
@@ -1383,7 +1383,8 @@ The commands are sorted on the non-optional part of their name.
|:put| :pu[t] insert contents of register in the text
|:pwd| :pw[d] print current directory
|:py3| :py3 execute Python 3 command
-|:p3yfile| :py3f[ile] execute Python 3 script file
+|:python3| :python3 same as :py3
+|:py3yfile| :py3f[ile] execute Python 3 script file
|:python| :py[thon] execute Python command
|:pyfile| :pyf[ile] execute Python script file
|:quit| :q[uit] quit current window (when one window quit Vim)
diff --git a/runtime/doc/todo.txt b/runtime/doc/todo.txt
index 9e2e3132e3..0b736ba069 100644
--- a/runtime/doc/todo.txt
+++ b/runtime/doc/todo.txt
@@ -30,6 +30,10 @@ be worked on, but only if you sponsor Vim development. See |sponsor|.
*known-bugs*
-------------------- Known bugs and current work -----------------------
+Include patch for horizontal scoll wheel? (Bjorn Winckler, 2010 Jul 20)
+
+Patch for Dynamic loading for Perl. (James Vega, 2010 Jul 20)
+
Cursor positioning wrong with 0x200e character. (John Becket, 2010 May 6)
Test 69 breaks on MS-Windows, both 32 and 64 builds. (George Reilly, 2010 Feb
diff --git a/src/ex_cmds.h b/src/ex_cmds.h
index e45796f69e..ee9098ae65 100644
--- a/src/ex_cmds.h
+++ b/src/ex_cmds.h
@@ -743,6 +743,8 @@ EX(CMD_pyfile, "pyfile", ex_pyfile,
RANGE|FILE1|NEEDARG|CMDWIN),
EX(CMD_py3, "py3", ex_py3,
RANGE|EXTRA|NEEDARG|CMDWIN),
+EX(CMD_python3, "python3", ex_py3,
+ RANGE|EXTRA|NEEDARG|CMDWIN),
EX(CMD_py3file, "py3file", ex_py3file,
RANGE|FILE1|NEEDARG|CMDWIN),
EX(CMD_quit, "quit", ex_quit,
diff --git a/src/ex_docmd.c b/src/ex_docmd.c
index 2d1a893d5a..760ac64983 100644
--- a/src/ex_docmd.c
+++ b/src/ex_docmd.c
@@ -2563,6 +2563,7 @@ do_one_cmd(cmdlinep, sourcing,
case CMD_psearch:
case CMD_python:
case CMD_py3:
+ case CMD_python3:
case CMD_return:
case CMD_rightbelow:
case CMD_ruby:
@@ -2825,9 +2826,10 @@ find_command(eap, full)
{
while (ASCII_ISALPHA(*p))
++p;
- /* for python 3.x support ":py3" (and ":py4" :-) */
+ /* for python 3.x support ":py3", ":python3", ":py3file", etc. */
if (eap->cmd[0] == 'p' && eap->cmd[1] == 'y')
- p = skipdigits(p);
+ while (ASCII_ISALNUM(*p))
+ ++p;
/* check for non-alpha command */
if (p == eap->cmd && vim_strchr((char_u *)"@*!=><&~#", *p) != NULL)